@@ -1,4 +1,23 @@
 """Defines the public isort interface"""
+__all__ = (
+    "Config",
+    "ImportKey",
+    "__version__",
+    "check_code",
+    "check_file",
+    "check_stream",
+    "code",
+    "file",
+    "find_imports_in_code",
+    "find_imports_in_file",
+    "find_imports_in_paths",
+    "find_imports_in_stream",
+    "place_module",
+    "place_module_with_reason",
+    "settings",
+    "stream",
+)
+
 from . import settings
 from ._version import __version__
 from .api import ImportKey
